#
# spec file for package ghc-SVGFonts
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name SVGFonts
Name:           ghc-%{pkg_name}
Version:        1.7
Release:        lp150.4.2
Summary:        Fonts from the SVG-Font format
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-blaze-markup-devel
BuildRequires:  ghc-blaze-svg-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-cereal-devel
BuildRequires:  ghc-cereal-vector-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-default-class-devel
BuildRequires:  ghc-diagrams-core-devel
BuildRequires:  ghc-diagrams-lib-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-xml-devel

%description
Native font support for the diagrams framework
(<http://projects.haskell.org/diagrams/>). Note that this package can be used
with any diagrams backend, not just the SVG backend. The SVG-font format is
easy to parse and was therefore chosen for a font library completely written in
Haskell.

You can convert your own font to SVG with <http://fontforge.github.io/>, or use
the included LinLibertine and Bitstream fonts.

Features:

* Complete implementation of the features that Fontforge produces (though not
the complete SVG format)

* Kerning (/i.e./ the two characters in "VA" are closer than the characters in
"VV")

* Unicode

* Ligatures

* An example that shows how to do text boxes with syntax highlighting using
highlighting-kate: <http://hackage.haskell.org/package/highlighting-kate>

XML speed issues can be solved by trimming the svg file to only those
characters that are used (or maybe binary xml one day).

Version 1.0 of this library supports texturing, though this only makes sense in
a diagrams backend that does rasterization in Haskell, such as
diagrams-rasterific.

Example:

> # LANGUAGE NoMonomorphismRestriction # > > main = do linLibertine <-
loadDataFont "fonts/LinLibertine.svg" > t <- text'''' linLibertine "Hello" >
mainWith (t :: Diagram B) > > text' font t = stroke (textSVG t 1) # fc purple #
fillRule EvenOdd > text'' font t = stroke (textSVG' (TextOpts font INSIDE_H
KERN False 1 1) t) # fillRule EvenOdd > text''' font t = (textSVG_ (TextOpts
font INSIDE_H KERN True 1 1) t) # fillRule EvenOdd > > -- using a local font >
text'''' font t = do > font <- loadFont "/path/to/font.svg" > return $ stroke
(textSVG' (TextOpts font INSIDE_H KERN False 1 1) t) .

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%dir %{_datadir}/%{pkg_name}-%{version}
%dir %{_datadir}/%{pkg_name}-%{version}/fonts
%{_datadir}/%{pkg_name}-%{version}/fonts/*.svg

%files devel -f %{name}-devel.files
%doc CHANGES.md README.md

%changelog
* Tue Jul 10 2018 psimons@suse.com
- Add SVGFonts at version 1.7.
